@@ -13,9 +13,9 @@ Usage::
     client: DocDBClient = session.client("docdb")
     ```
 """
+
 import sys
-from datetime import datetime
-from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -89,10 +89,11 @@ from .type_defs import (
     StopDBClusterResultTypeDef,
     TagListMessageTypeDef,
     TagTypeDef,
+    TimestampTypeDef,
 )
 from .waiter import DBInstanceAvailableWaiter, DBInstanceDeletedWaiter
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -212,7 +213,8 @@ class DocDBClient(BaseClient):
     ) -> ApplyPendingMaintenanceActionResultTypeDef:
         """
         Applies a pending maintenance action to a resource (for example, to an Amazon
-        DocumentDB instance).
+        DocumentDB
+        instance).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#apply_pending_maintenance_action)
@@ -342,7 +344,8 @@ class DocDBClient(BaseClient):
         CopyTagsToSnapshot: bool = ...,
         PromotionTier: int = ...,
         EnablePerformanceInsights: bool = ...,
-        PerformanceInsightsKMSKeyId: str = ...
+        PerformanceInsightsKMSKeyId: str = ...,
+        CACertificateIdentifier: str = ...
     ) -> CreateDBInstanceResultTypeDef:
         """
         Creates a new instance.
@@ -397,7 +400,8 @@ class DocDBClient(BaseClient):
     ) -> CreateGlobalClusterResultTypeDef:
         """
         Creates an Amazon DocumentDB global cluster that can span multiple multiple
-        Amazon Web Services Regions.
+        Amazon Web Services
+        Regions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.create_global_cluster)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#create_global_cluster)
@@ -483,7 +487,8 @@ class DocDBClient(BaseClient):
     ) -> CertificateMessageTypeDef:
         """
         Returns a list of certificate authority (CA) certificates provided by Amazon
-        DocumentDB for this Amazon Web Services account.
+        DocumentDB for this Amazon Web Services
+        account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.describe_certificates)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#describe_certificates)
@@ -525,7 +530,8 @@ class DocDBClient(BaseClient):
     ) -> DescribeDBClusterSnapshotAttributesResultTypeDef:
         """
         Returns a list of cluster snapshot attribute names and values for a manual DB
-        cluster snapshot.
+        cluster
+        snapshot.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#describe_db_cluster_snapshot_attributes)
@@ -625,7 +631,8 @@ class DocDBClient(BaseClient):
     ) -> DescribeEngineDefaultClusterParametersResultTypeDef:
         """
         Returns the default engine and system parameter information for the cluster
-        database engine.
+        database
+        engine.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#describe_engine_default_cluster_parameters)
@@ -636,7 +643,8 @@ class DocDBClient(BaseClient):
     ) -> EventCategoriesMessageTypeDef:
         """
         Displays a list of categories for all event source types, or, if specified, for
-        a specified source type.
+        a specified source
+        type.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.describe_event_categories)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#describe_event_categories)
@@ -662,8 +670,8 @@ class DocDBClient(BaseClient):
         *,
         SourceIdentifier: str = ...,
         SourceType: SourceTypeType = ...,
-        StartTime: Union[datetime, str] = ...,
-        EndTime: Union[datetime, str] = ...,
+        StartTime: TimestampTypeDef = ...,
+        EndTime: TimestampTypeDef = ...,
         Duration: int = ...,
         EventCategories: Sequence[str] = ...,
         Filters: Sequence[FilterTypeDef] = ...,
@@ -672,7 +680,8 @@ class DocDBClient(BaseClient):
     ) -> EventsMessageTypeDef:
         """
         Returns events related to instances, security groups, snapshots, and DB
-        parameter groups for the past 14 days.
+        parameter groups for the past 14
+        days.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.describe_events)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#describe_events)
@@ -722,7 +731,8 @@ class DocDBClient(BaseClient):
     ) -> PendingMaintenanceActionsMessageTypeDef:
         """
         Returns a list of resources (for example, instances) that have at least one
-        pending maintenance action.
+        pending maintenance
+        action.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#describe_pending_maintenance_actions)
@@ -777,6 +787,7 @@ class DocDBClient(BaseClient):
         PreferredMaintenanceWindow: str = ...,
         CloudwatchLogsExportConfiguration: CloudwatchLogsExportConfigurationTypeDef = ...,
         EngineVersion: str = ...,
+        AllowMajorVersionUpgrade: bool = ...,
         DeletionProtection: bool = ...
     ) -> ModifyDBClusterResultTypeDef:
         """
@@ -806,7 +817,8 @@ class DocDBClient(BaseClient):
     ) -> ModifyDBClusterSnapshotAttributeResultTypeDef:
         """
         Adds an attribute and values to, or removes an attribute and values from, a
-        manual cluster snapshot.
+        manual cluster
+        snapshot.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#modify_db_cluster_snapshot_attribute)
@@ -825,7 +837,8 @@ class DocDBClient(BaseClient):
         CopyTagsToSnapshot: bool = ...,
         PromotionTier: int = ...,
         EnablePerformanceInsights: bool = ...,
-        PerformanceInsightsKMSKeyId: str = ...
+        PerformanceInsightsKMSKeyId: str = ...,
+        CertificateRotationRestart: bool = ...
     ) -> ModifyDBInstanceResultTypeDef:
         """
         Modifies settings for an instance.
@@ -903,7 +916,8 @@ class DocDBClient(BaseClient):
     ) -> RemoveSourceIdentifierFromSubscriptionResultTypeDef:
         """
         Removes a source identifier from an existing Amazon DocumentDB event
-        notification subscription.
+        notification
+        subscription.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/docdb.html#DocDB.Client.remove_source_identifier_from_subscription)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_docdb/client/#remove_source_identifier_from_subscription)
@@ -947,7 +961,8 @@ class DocDBClient(BaseClient):
         Tags: Sequence[TagTypeDef] = ...,
         KmsKeyId: str = ...,
         EnableCloudwatchLogsExports: Sequence[str] = ...,
-        DeletionProtection: bool = ...
+        DeletionProtection: bool = ...,
+        DBClusterParameterGroupName: str = ...
     ) -> RestoreDBClusterFromSnapshotResultTypeDef:
         """
         Creates a new cluster from a snapshot or cluster snapshot.
@@ -962,7 +977,7 @@ class DocDBClient(BaseClient):
         DBClusterIdentifier: str,
         SourceDBClusterIdentifier: str,
         RestoreType: str = ...,
-        RestoreToTime: Union[datetime, str] = ...,
+        RestoreToTime: TimestampTypeDef = ...,
         UseLatestRestorableTime: bool = ...,
         Port: int = ...,
         DBSubnetGroupName: str = ...,
